@@ -27,19 +27,19 @@
 #' library(sp);library(raster)
 #'
 #' ## Exemplary input Polygon with 2km x 2km:
-#' polYgon <- Polygon(rbind(c(0, 0), c(0, 2000), c(2000, 2000), c(2000, 0)))
+#'  polYgon <- Polygon(rbind(c(0, 0), c(0, 2000), c(2000, 2000), c(2000, 0)))
 #' polYgon <- Polygons(list(polYgon),1);
 #' polYgon <- SpatialPolygons(list(polYgon))
 #' Projection <- "+proj=laea +lat_0=52 +lon_0=10 +x_0=4321000 +y_0=3210000
 #'                +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs"
 #' proj4string(polYgon) <- CRS(Projection); plot(polYgon,axes=TRUE)
-#'
+#' 
 #' ## Create a random windfarm with 10 turbines
 #' t <- as.matrix(cbind(x=runif(10,0,raster::extent(polYgon)[2]),
 #'      y=runif(10,0,raster::extent(polYgon)[4])))
 #' wnkl <- 20
 #' distanz <- 100000
-#'
+#' 
 #' ## Evaluate and plot for every turbine all other potentially influencing turbines
 #' potInfTur <- list()
 #' for (i in 1:(length(t[,1]))) {
@@ -80,7 +80,7 @@ VekWinkelCalc     <- function(t,o, wkl, distanz, polYgon, plotAngles) {
       data <- t(as.matrix(c(as.numeric(P2LFu), as.numeric(winkel))));
       colN <- t(as.matrix(c(colnames(P2LFu),colnames(winkel))));
       datalist[[indx]] <- data;
-      datalun <- data.frame(matrix(unlist(datalist), nrow=(length(datalist)), byrow = TRUE));
+      datalun <- as.data.frame(matrix(unlist(datalist), nrow=(length(datalist)), byrow = TRUE));
       colnames(datalun) <- colN;
       ## Dismiss the ones with too high distances or big angles.
       datalun <- subset.data.frame(datalun,subset = datalun$alpha<wkl & datalun$Laenge_B<distanz);
@@ -100,14 +100,14 @@ VekWinkelCalc     <- function(t,o, wkl, distanz, polYgon, plotAngles) {
     ## If no possible influencing turbines remain and the variable "datalun" therefoe doesnt exist,
     ## the variable "DataLun3" is fulled with default Values of 0 for distances and angles
     if (!exists("datalun")) {
-      dfm3 <- data.frame(matrix(data = c(0,0,t[o,1],t[o,2],(rep(0,8))),nrow = 1, ncol = 12));
+      dfm3 <- as.data.frame(matrix(data = c(0,0,t[o,1],t[o,2],(rep(0,8))),nrow = 1, ncol = 12));
       colnames(dfm3) <- c("Ax","Ay","Bx","By","Cx","Cy","Laenge_C","Laenge_B","Laenge_A","alpha","betha","gamma");
       DataLun3 <- dfm3;
     }
 
   } else  {
     # If no turbines are in front, the variabel "DataLun3" is again filled with default values of 0 for angles and distances.
-    dfm4 <- data.frame(matrix(data = c(0,0,t[o,1],t[o,2],(rep(0,8))),nrow = 1, ncol = 12));
+    dfm4 <- as.data.frame(matrix(data = c(0,0,t[o,1],t[o,2],(rep(0,8))),nrow = 1, ncol = 12));
     colnames(dfm4) <- c("Ax","Ay","Bx","By","Cx","Cy","Laenge_C","Laenge_B","Laenge_A","alpha","betha","gamma");
     DataLun3 <- dfm4;
   }
