@@ -36,6 +36,9 @@
 #' }
 #' @author Sebastian Gatscha
 heatmapGA <- function(result,si=2,idistw){
+  opar = par(no.readonly = T)
+  par(mfrow=c(1,1))
+  
   bpe <- do.call("rbind",result[,'allCoords']);
   bpe <- bpe[c(1,2)]
 
@@ -78,5 +81,5 @@ heatmapGA <- function(result,si=2,idistw){
 
   plot1+ggplot2::scale_fill_gradient(low="red", high="green")+ggplot2::coord_equal()
 
-
+  par(opar)
 }
